/* Header for parsing htmlscrub configuration files */

#if ! defined CFG_H
#define CFG_H

/* Recognized tokens.  Note that we don't enumerate keywords,  */
/* because anything we designate as a keyword might show up as */
/* a tag name or attribute name.  So we leave the recognition  */
/* of keywords to semantic analysis because it depends on      */
/* context. */

typedef enum
{
	T_ERROR = 1,
	T_EOF,
	T_LT,         /* '<' */
	T_GT,         /* '>' */
	T_COLON,      /* ':' */
	T_LBRACE,     /* '{' */
	T_RBRACE,     /* '}' */
	T_WORD,       /* any string of characters and/or digits */
} CfgTokType;

#define CFG_TEXT_MAX 127
#define TAG_LEN_MAX 35

typedef enum
{
	CFGA_KEEP,
	CFGA_WARN,
	CFGA_DROP,
	CFGA_DROP_ALL,
	CFGA_EDIT
} CfgActionType;

typedef struct
{
	CfgTokType type;
	char text[ CFG_TEXT_MAX + 1 ];
} CfgTok;

/* Opaque pointer to a structure */
/* representing a configuration  */

typedef struct
{
	void * p;
} Config;

#if defined __cplusplus
extern "C"
{
#endif

int cfg_read( FILE * cfg_file, Config cfg );

CfgActionType cfg_action( Config config, const char * tag );
CfgActionType cfg_attr_action( Config config, const char * tag,
	const char * attr );
CfgActionType cfg_comment_action( Config config );
int cfg_tok( CfgTok * pTok, FILE * cfg_file );
int cfg_set_tag_action( Config config, const char * tag,
	CfgActionType type );
int cfg_set_comment_action( Config config, CfgActionType type );
int cfg_set_tag_default( Config config, CfgActionType type );
int cfg_set_attr_default( Config config, const char * tag,
	CfgActionType type );
int cfg_set_attr_action( Config config, const char * tag,
	const char * attr_name, CfgActionType type );
int cfg_valid( Config config );
Config cfg_construct( void );
void cfg_destruct( Config * pConfig );

#if defined __cplusplus
}
#endif

#endif
