/*-------------------------------------------------------
 Header for Estr functions.

 An Estr is an Expandable String -- a sort of poor man's
 string class for C.  It stores an internal character
 array, expanding it as needed.
 ------------------------------------------------------*/
#if ! defined ESTR_H

typedef void ( * Estr_error_reporter )( const char * msg );

/* typedef for an Estr: struct containing an opaque pointer */
/* pointing to the implementation (pimpl idiom) */

typedef struct
{
	void * p;
} Estr;

#if defined __cplusplus
extern "C"
{
#endif

Estr_error_reporter estr_install_error_reporter( Estr_error_reporter pR );

/* constructors */

Estr estr_construct( void );
Estr estr_construct_n( size_t n );
Estr estr_construct_str( const char * s );
Estr estr_construct_mem( const void * p, size_t n );

/* destructor */

void estr_destruct( Estr * pEstr );

/* assignment */

int estr_assign_str( Estr estr, const char * s );

/* accessors */

int estr_valid( Estr estr );
size_t estr_size( Estr estr );
const char * estr_c_str( Estr estr );

/* updaters */

void estr_clear( Estr estr );
int estr_append_c( Estr estr, char c );
int estr_append_str( Estr estr, const char * s );
int estr_append_mem( Estr estr, const char * s, size_t n );

#if defined __cplusplus
}
#endif

#endif
